import { useRoute, useRouter } from 'vue-router'
import { cloneDeep } from 'lodash-es'
import useTabs from '@/utils/useTabs'
import extendFieldApi from '@/api/base/extendfield/extendFieldApi'

export default function useFormHandler(formItems, api, backRouter) {
	const state = reactive({
		PAGE_TYPE: ''
	})

	const extendFormData = ref({})
	const inform = reactive({
		createUserName: '',
		createTime: '',
		updateUserName: '',
		updateTime: ''
	})

	const formData = reactive({})
	const submitLoading = ref(false)
	const formRefs = ref([])

	const route = useRoute()
	const router = useRouter()

	// 初始化表单数据
	const initializeFormData = () => {
		formItems.forEach((item) => {
			formData[item.name] = item.defaultValue || null
		})
	}

	// 提交表单
	const onSubmit = async (params = {}) => {
		submitLoading.value = true
		try {
			await validateForms()

			const formDataParam = params.isDeep ? cloneDeep(params) : formData
			const safeId = validateAndCleanId(route.query.id || params.id)
			if (safeId) {
				formDataParam.id = safeId
			}

			const res = await api.submitForm(formDataParam, safeId)

			if (params.isEnable) return res

			handleBack()
		} catch (error) {
			console.error('Validation or submission error:', error)
			throw error
		} finally {
			submitLoading.value = false
		}
	}

	// 验证表单
	const validateForms = () => {
		return Promise.all(formRefs.value.map((form) => form.validate()))
	}

	// 校验并清洁ID
	const validateAndCleanId = (id) => {
		return id && /^[a-zA-Z0-9\-_]+$/.test(id) ? id : undefined
	}

	// 返回并关闭当前标签页
	const handleBack = () => {
		useTabs.close('', backRouter)
	}

	// 根据页面类型加载表单数据
	const fetchData = async (pageType) => {
		initializeFormData()
		if (pageType && pageType !== 'ADD') {
			try {
				const res = await api.getDetail({ id: route.query.id })
				populateFormData(res)
				if (res.extJson) {
					extendFormData.value = JSON.parse(res.extJson)
				}
				return res
			} catch (error) {
				console.error('Failed to fetch data:', error)
			}
		}
	}

	// 填充表单数据
	const populateFormData = (data) => {
		console.log(formData, 'formData')
		Object.keys(formData).forEach((key) => {
			if (data[key] !== undefined) formData[key] = data[key]
		})

		Object.keys(inform).forEach((key) => {
			if (data[key] !== undefined) inform[key] = data[key]
		})
	}

	// 获取扩展字段
	const getExtendField = async (model) => {
		try {
			const resExtendField = await extendFieldApi.extendFieldTypeList({
				enabledState: 'ENABLE',
				model
			})

			const extendData =
				resExtendField?.map((item) => {
					if (item.enabledState === 'ENABLE') {
						const options = item.showValues
							? JSON.parse(item.showValues).map((value) => ({
									value: value.name,
									label: value.name
							  }))
							: []
						return {
							label: item.name,
							name: item.fieldName,
							type: item.showType,
							span: 6,
							attrs: {
								placeholder: '请输入内容',
								options
							}
						}
					}
				}) || []

			extendData.forEach((item) => {
				if (item && item.fieldName) extendFormData.value[item.fieldName] = null
			})

			if (extendData) {
				return extendData
			} else {
				return []
			}
		} catch (error) {
			console.error('Failed to get extend fields:', error)
			return []
		}
	}

	return {
		formData,
		submitLoading,
		formRefs,
		inform,
		extendFormData,
		populateFormData,
		getExtendField,
		onSubmit,
		handleBack,
		fetchData,
		initializeFormData
	}
}
