import { required } from '@/utils/formRules'
import tool from '@/utils/tool'

export const formRules = {
	name: [required('请输入名称')],
	type: [required('请输入类型')],
	appid: [required('请输入AppID')],
	secret: [required('请输入AppSecret')]
}

export const materialFormItems = [
	{
		label: '编码：',
		name: 'number',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入编码'
		}
	},
	{
		label: '名称：',
		name: 'name',
		type: 'a-input',
		span: 6,
		rules: [required('请输入名称')],
		attrs: {
			placeholder: '请输入名称',
			allowClear: true
		}
	},
	{
		label: '简称：',
		name: 'shortName',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入简称',
			allowClear: true
		}
	},
	{
		label: '别名：',
		name: 'alias',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入别名',
			allowClear: true
		}
	},
	{
		label: '规格型号：',
		name: 'specification',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入规格型号',
			allowClear: true
		}
	},
	{
		label: '包装比例：',
		name: 'packageProportion',
		type: 'a-input',
		span: 6,
		rules: [required('请输入包装比例')],
		attrs: {
			placeholder: '请输入包装比例',
			allowClear: true,
			disabled: true
		}
	},
	{
		label: '助记码：',
		name: 'mnemonicCode',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入助记码',
			allowClear: true
		}
	},
	{
		label: '可用状态：',
		name: 'enabledState',
		type: 'a-select',
		span: 6,
		attrs: {
			placeholder: '请选择可用状态',
			options: tool.dictList('COMMON_STATUS')
		},
		defaultValue: 'ENABLE'
	}
]

export const baseFormItems = reactive([
	{
		label: '物料类型：',
		name: 'categoryId',
		type: 'a-tree-select',
		span: 6,
		rules: [required('请选择物料类型')],
		attrs: {
			placeholder: '请选择物料类型',
			treeData: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			}
		}
	},
	{
		label: '品牌：',
		name: 'brandId',
		type: 'a-select',
		span: 6,
		attrs: {
			placeholder: '请选择品牌',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			}
		}
	},
	{
		label: '最高库存：',
		name: 'maxInventory',
		type: 'a-input-number',
		span: 6,
		attrs: {
			placeholder: '请输入最高库存'
		}
	},
	{
		label: '最低库存：',
		name: 'minInventory',
		type: 'a-input-number',
		span: 6,
		attrs: {
			placeholder: '请输入最高库存'
		}
	},
	{
		label: '保质期：',
		name: 'shelfLife',
		type: 'a-input-number',
		span: 6,
		rules: [required('请选择保质期')],
		attrs: {
			placeholder: '请输入保质期',
			allowClear: true
		}
	},
	// {
	// 	label: '统一零售价：',
	// 	name: 'retailPrice',
	// 	type: 'a-input-number',
	// 	span: 6,
	// 	attrs: {
	// 		placeholder: '请输入统一零售价',
	// 		allowClear: true
	// 	}
	// },
	{
		label: '商品条形码：',
		name: 'barcode',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入商品条形码',
			allowClear: true
		}
	},
	{
		label: '保质期单位：',
		name: 'shelfLifeUnit',
		type: 'a-select',
		span: 6,
		rules: [required('请选择保质期单位')],
		attrs: {
			placeholder: '请选择保质期单位',
			options: tool.dictList('DATE_UNIT')
		}
	},
	{
		label: '最大包装数量：',
		name: 'maxPackageQuantity',
		type: 'a-input-number',
		span: 6,
		rules: [required('请输入最大包装数量')],
		attrs: {
			placeholder: '请输入最大包装数量',
			allowClear: true
		}
	},
	{
		label: '批次管理：',
		name: 'batchManage',
		type: 'a-select',
		span: 6,
		attrs: {
			placeholder: '请选择批次管理',
			options: tool.dictList('COMMON_STATUS')
		}
	},
	{
		label: '备注：',
		name: 'remarks',
		type: 'a-textarea',
		span: 24,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	}
])

export const unitFormItems = reactive([
	{
		label: '单位组：',
		name: 'unitGroupId',
		type: 'a-select',
		span: 6,
		rules: [required('请选择单位组')],
		attrs: {
			placeholder: '请选择类型',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '基本单位：',
		name: 'baseUnitId',
		type: 'a-select',
		span: 6,
		attrs: {
			placeholder: '请选择类型',
			options: [],
			disabled: true,
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '采购单位：',
		name: 'purchaseUnitId',
		type: 'a-select',
		span: 6,
		rules: [required('请选择采购单位')],
		attrs: {
			placeholder: '请选择类型',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '分销单位：',
		name: 'distrUnitId',
		type: 'a-select',
		span: 6,
		rules: [required('请选择分销单位')],
		attrs: {
			placeholder: '请输入备注',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '生产单位：',
		name: 'produceUnitId',
		type: 'a-select',
		span: 6,
		rules: [required('请选择生产单位')],
		attrs: {
			placeholder: '请输入备注',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '销售单位：',
		name: 'saleUnitId',
		type: 'a-select',
		span: 6,
		rules: [required('请选择销售单位')],
		attrs: {
			placeholder: '请输入备注',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	},
	{
		label: '库存单位：',
		name: 'storeUnitId',
		type: 'a-select',
		rules: [required('请选择库存单位')],
		span: 6,
		attrs: {
			placeholder: '请输入备注',
			options: [],
			fieldNames: {
				label: 'name',
				value: 'id'
			},
			allowClear: true
		}
	}
])

export const priceFormItems = [
	{
		label: '生产价格：',
		name: 'producePrice',
		type: 'a-input',
		span: 6,
		rules: [required('请输入生产价格')],
		attrs: {
			placeholder: '请输入生产价格'
		}
	},
	{
		label: '采购价格：',
		name: 'purchasePrice',
		type: 'a-input-number',
		span: 6,
		rules: [required('请输入采购价格')],
		attrs: {
			placeholder: '请输入生产价格'
		}
	},
	{
		label: '统一零售价：',
		name: 'retailPrice',
		type: 'a-input-number',
		span: 6,
		rules: [required('请输入统一零售价')],
		attrs: {
			placeholder: '请输入生产价格'
		}
	}
]
