import { required } from '@/utils/formRules'
import tool from '@/utils/tool'

export const officialAccountFormItems = reactive([
	{
		label: '编码：',
		name: 'number',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择编码'
		}
	},
	{
		label: '名称：',
		name: 'name',
		type: 'a-input',
		span: 6,
		rules: [required('请输入名称')],
		attrs: {
			placeholder: '请输入名称',
			allowClear: true
		}
	},
	{
		label: '仓库条码：',
		name: 'barcode',
		type: 'a-input',
		span: 6,
		rules: [required('请输入仓库条码')],
		attrs: {
			placeholder: '请输入仓库条码',
			allowClear: true
		}
	},
	{
		label: '可用状态：',
		name: 'enabledState',
		type: 'a-select',
		span: 6,
		attrs: {
			placeholder: '请选择可用状态',
			options: tool.dictList('COMMON_STATUS')
		},
		defaultValue: 'ENABLE'
	},
	{
		label: '库存管理方式：',
		name: 'manageMode',
		type: 'a-select',
		span: 6,
		rules: [required('请选择库存管理方式')],
		attrs: {
			placeholder: '请选择库存管理方式',
			options: tool.dictList('STORE_MANAGE_MODE')
		},
		defaultValue: ''
	},
	{
		label: '上游仓库：',
		name: 'parentId',
		type: 'a-tree-select',
		span: 6,
		attrs: {
			placeholder: '请选择上游仓库',
			treeData: [],
			fieldNames: {
				children: 'children',
				label: 'name',
				value: 'id'
			}
		},
		defaultValue: ''
	},
	{
		label: '备注：',
		name: 'remarks',
		type: 'a-textarea',
		span: 24,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	}
])

export const baseFormItems = [
	{
		label: '管理员：',
		name: 'manageUserName',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择管理员',
			readonly: true
		}
	},
	{
		label: '手机：',
		name: 'phone',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入手机'
		}
	},
	{
		label: '固话：',
		name: 'tel',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择固话'
		}
	},
	{
		label: '地址：',
		name: 'address',
		type: 'a-textarea',
		span: 24,
		attrs: {
			placeholder: '请输入地址',
			allowClear: true
		}
	}
]

export const formRules = {
	name: [required('请输入名称')],
	type: [required('请输入类型')],
	appid: [required('请输入AppID')],
	secret: [required('请输入AppSecret')]
}
