import { required } from '@/utils/formRules'
import tool from '@/utils/tool'

export const formRules = {
	name: [required('请输入名称')]
}

export const formItems = reactive([
	{
		label: '编码：',
		name: 'number',
		type: 'a-input',
		span: 8,
		attrs: {
			placeholder: '请输入编码若留空由系统自动生成',
			allowClear: true
		}
	},
	{
		label: '名称：',
		name: 'name',
		type: 'a-input',
		span: 8,
		rules: [required('请输入名称')],
		attrs: {
			placeholder: '请输入名称',
			allowClear: true
		}
	},
	{
		label: '简称：',
		name: 'shortName',
		type: 'a-input',
		span: 8,
		attrs: {
			placeholder: '请输入简称',
			allowClear: true
		}
	},
	{
		label: '可用状态：',
		name: 'enabledState',
		type: 'a-select',
		span: 8,
		attrs: {
			placeholder: '请选择可用状态',
			options: tool.dictList('COMMON_STATUS')
		},
		defaultValue: 'ENABLE'
	},
	{
		label: '品牌：',
		name: 'brandId',
		type: 'a-select',
		span: 8,
		// rules: [required('请选择品牌')],
		attrs: {
			placeholder: '请选择品牌',
			options: tool.dictList('COMMON_STATUS'),
			fieldNames: {
				label: 'name',
				value: 'id'
			}
		}
	},
	{
		label: '供应商分类：',
		name: 'categoryId',
		type: 'a-tree-select',
		span: 8,
		rules: [required('请选择分类')],
		attrs: {
			placeholder: '请选择分类',
			allowClear: true,
			fieldNames: {
				children: 'children',
				label: 'name',
				value: 'id'
			}
		}
	},
	{
		label: '省：',
		name: 'province',
		span: 8,
		// rules: [required('请选择省')],
		isUseSlot: true,
		slotName: 'provinceSlot',
		attrs: {
			placeholder: '请选择省'
		}
	},
	{
		label: '市：',
		name: 'city',
		span: 8,
		// rules: [required('请选择市')],
		isUseSlot: true,
		slotName: 'citySlot'
	},
	{
		label: '区：',
		name: 'county',
		// rules: [required('请选择区')],
		isUseSlot: true,
		slotName: 'countySlot',
		span: 8
	},
	{
		label: '详细地址：',
		name: 'address',
		type: 'a-textarea',
		span: 8,
		attrs: {
			placeholder: '请输入详细地址',
			allowClear: true,
			fieldNames: {
				children: 'children',
				label: 'name',
				value: 'id'
			}
		}
	},
	{
		label: '备注：',
		name: 'remarks',
		type: 'a-textarea',
		span: 8,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	}
])

export const baseFormItems = [
	{
		label: '联系人：',
		name: 'contacts',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择类型'
		}
	},
	{
		label: '手机：',
		name: 'phone',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择类型'
		}
	},
	{
		label: '固话：',
		name: 'tel',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择类型'
		}
	},
	{
		label: '传真：',
		name: 'fax',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请选择类型'
		}
	},
	{
		label: '电子邮箱：',
		name: 'email',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	},
	{
		label: 'QQ：',
		name: 'qq',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	},
	{
		label: '微信：',
		name: 'wechat',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	},
	{
		label: '联系地址：',
		name: 'contactAddress',
		type: 'a-input',
		span: 6,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	}
]
