import tool from '@/utils/tool'
import { required } from '@/utils/formRules'

const basicInfoFormRules = {
	type: [required('请选择类型')],
	businessDate: [required('请选择业务日期')],
	storeId: [required('请选择仓库')],
	customerName: [required('请选择客户')]
}

const basicInfoFormItems = [
	{
		label: '单据号：',
		name: 'billNumber',
		type: 'a-input',
		attrs: {
			placeholder: '请输入单号',
			allowClear: true
		}
	},
	{
		label: '业务日期：',
		name: 'businessDate',
		type: 'a-date-picker',
		attrs: {
			placeholder: '请选择业务日期',
			allowClear: true,
			valueFormat: 'YYYY-MM-DD HH:mm:ss'
		}
	},
	{
		label: '类型：',
		name: 'type',
		type: 'a-select',
		attrs: {
			placeholder: '请选择类型',
			allowClear: true,
			options: tool.dictList('OUTBOUND_TYPE')
		}
	},
	{
		label: '客户：',
		name: 'customerName',
		type: 'a-input',
		isUseSlot: true,
		slotName: 'customerNameSlot',
		attrs: {
			placeholder: '请选择客户'
		}
	},
	{
		label: '仓库：',
		name: 'storeId',
		type: 'a-tree-select',
		span: 6,
		attrs: {
			placeholder: '请选择仓库',
			treeData: [],
			fieldNames: {
				children: 'children',
				label: 'name',
				value: 'id'
			}
		},
		defaultValue: ''
	},
	{
		label: '车牌号：',
		name: 'carNumber',
		type: 'a-input',
		attrs: {
			placeholder: '请输入车牌号',
			allowClear: true
		}
	},
	{
		label: '停车位：',
		name: 'parkingSpace',
		type: 'a-input',
		attrs: {
			placeholder: '请输入停车位',
			allowClear: true
		}
	},
	{
		label: '业务员：',
		name: 'salesman',
		type: 'a-input',
		attrs: {
			placeholder: '请输入业务员',
			allowClear: true
		}
	},
	{
		label: '收货方：',
		name: 'receiveParty',
		type: 'a-input',
		attrs: {
			placeholder: '请输入收货方',
			allowClear: true
		}
	},
	{
		label: '交货日期：',
		name: 'deliveryDate',
		type: 'a-date-picker',
		attrs: {
			placeholder: '请选择交货日期',
			allowClear: true,
			valueFormat: 'YYYY-MM-DD HH:mm:ss'
		}
	},
	{
		label: '交货地址：',
		name: 'deliveryAddress',
		type: 'a-input',
		attrs: {
			placeholder: '请输入交货地址',
			allowClear: true
		}
	},
	{
		label: '备注：',
		name: 'remarks',
		type: 'a-textarea',
		span: 24,
		attrs: {
			placeholder: '请输入备注',
			allowClear: true
		}
	}
]

const productDetailFormItems = [
	{
		title: '序号',
		dataIndex: 'index',
		editable: true,
		width: 80
	},
	{
		title: '商品名称',
		dataIndex: 'productName',
		editable: true,
		width: 300,
		dataType: 'select' // 或 'number', 'select'
	},
	{
		title: '商品编码',
		dataIndex: 'productNumber',
		editable: true,
		width: 300
	},
	{
		title: '规格型号',
		dataIndex: 'specification',
		editable: true,
		width: 300
	},
	{
		title: '基本单位',
		dataIndex: 'baseUnitName',
		editable: true,
		width: 300
	},
	{
		title: '批次号',
		dataIndex: 'batchNumber',
		width: 300,
		editable: true
	},
	{
		title: '单位',
		dataIndex: 'unitName',
		width: 300,
		editable: true
	},
	{
		title: '计划数量',
		dataIndex: 'planAmount',
		width: 300,
		editable: true,
		dataType: 'number' // 或 'number', 'select'
	}
]

export { basicInfoFormRules, basicInfoFormItems, productDetailFormItems }
